<?php
if (!defined('ABSPATH')) die;

class buzzblogpro_widget_featured_post extends WP_Widget {

	protected $defaults;

	function __construct() {

		$this->defaults = array(
			'title' => '',
			'the_post' => '',
			'hide_image' => '',
			'hide_title' => '',
			'hide_comment' => '',
			'hide_date' => '',
			'hide_author' => '',
			'hide_excerpt' => '',
			'hide_button' => '',
			'hide_category' => '',
			'thumb_width' => '859',
			'thumb_height'=> '490',
			'excerpt_length'=> '12'
		);

		$widget_ops = array(
			'classname' => 'hercules_widget_featured_post',
			'description' => __('Displays a featured post of your choice.', 'buzzblogpro'),
		);

		$control_ops = array(
			'id_base' => 'buzzblogpro_widget_featured_post',
		);

		parent::__construct('buzzblogpro_widget_featured_post', 'Hercules - '.esc_html__('Featured Post', 'buzzblogpro'), $widget_ops, $control_ops);

	}

	// The widget content.
	function widget($args, $instance) {
		
		//* Merge with defaults
		$instance = wp_parse_args((array) $instance, $this->defaults);

		echo $args['before_widget'];

			if (! empty($instance['title']))
				echo $args['before_title'] . apply_filters('widget_title', $instance['title'], $instance, $this->id_base) . $args['after_title'];
			
			$post_id = absint($instance['the_post']);
			$excerpt_count = isset($instance['excerpt_length']) ? $instance['excerpt_length'] : '12';
			$link = esc_url(get_permalink($post_id));
			$arguments  = array( 'p' => $post_id, 'post_type' => 'post', 'posts_per_page' => 1, 'post__not_in' => get_option( 'sticky_posts' ), 'ignore_sticky_posts' => 1 );
			$query_featured_post = new WP_Query( $arguments );
		if ( $query_featured_post->have_posts() ) :
			while ( $query_featured_post->have_posts() ) : $query_featured_post->the_post();

			
			if (empty($instance['hide_image'])) {
			 
					$argsy = array(
		'width'          => isset($instance['thumb_width']) ? $instance['thumb_width'] : 859,
		'height'         => isset($instance['thumb_height']) ? $instance['thumb_height'] : 490,
		'crop'           => true,
		'single'           => true,
		'reviewscore'     => true,
		'gif'          => true, 
		'pinit'          => true,	
		'class' => 'nopin nolazyload',
        );
 
			            if ( has_post_thumbnail() ) {
				            buzzblogpro_post_thumbnail( $argsy );   
			            } 

			}

			
	echo '<div class="cover-content">';
	
	if (empty($instance['hide_category'])) {
						buzzblogpro_post_category('',' '); 
						}

	if (empty($instance['hide_title'])) {  ?>
	
	<h2 class="post-title entry-title"><a href="<?php esc_url(the_permalink()); ?>" title="<?php the_title_attribute(); ?>"><?php esc_attr(the_title()); ?></a></h2>
	<?php 
	 } 
	
	$whattoshow = array();
	if (empty($instance['hide_author'])) {
	$whattoshow[] = 'author';
	}
	if (empty($instance['hide_date'])) {
	$whattoshow[] = 'date';
	}
	if (empty($instance['hide_comment'])) {
	$whattoshow[] = 'comments';
	}
    buzzblogpro_post_meta($whattoshow, true, 'meta-space-top'); 
	
			if (empty($instance['hide_excerpt'])) {
								
				$excerpt = get_the_excerpt();
	            echo '<div class="excerpt">'.buzzblogpro_limit_text($excerpt,$excerpt_count).'</div>';
	
				
			}
			if (empty($instance['hide_button'])) {
				echo '<div class="viewpost-button"><a class="button" href="'.$link.'"><span>'.theme_locals("continue_reading").'</span></a></div>';
				
			}
			echo '</div>';
			
			endwhile;
			wp_reset_postdata();
			endif; 

		echo $args['after_widget'];

	}

	// Update a particular instance.
	function update($new_instance, $old_instance) {

		$new_instance['title'] = strip_tags($new_instance['title']);
		$new_instance['hide_image'] = strip_tags($new_instance['hide_image']);
		$new_instance['hide_title'] = strip_tags($new_instance['hide_title']);
		$new_instance['hide_author'] = strip_tags($new_instance['hide_author']);
		$new_instance['hide_date'] = strip_tags($new_instance['hide_date']);
		$new_instance['hide_comment'] = strip_tags($new_instance['hide_comment']);
		$new_instance['hide_excerpt'] = strip_tags($new_instance['hide_excerpt']);
		$new_instance['hide_button'] = strip_tags($new_instance['hide_button']);
		$new_instance['hide_category'] = strip_tags($new_instance['hide_category']);
		$new_instance['thumb_width'] = absint($new_instance['thumb_width']);
		$new_instance['thumb_height'] = absint($new_instance['thumb_height']);
		$new_instance['excerpt_length'] = absint($new_instance['excerpt_length']);
		$new_instance['the_post'] = absint($new_instance['the_post']);

		return $new_instance;

	}

	// The settings update form.
	function form($instance) {

		// Merge with defaults
		$instance = wp_parse_args((array) $instance, $this->defaults);

		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
			<input type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php if (isset($instance['title'])) echo esc_attr($instance['title']); ?>" class="widefat" />
		</p>
		
		<?php
		$args = array(
			'posts_per_page'=> 150,
			'post_type' => 'post',
			'post_status' => 'publish',
		);

		$posts_array = get_posts($args);
		
		if (isset($instance['the_post'])) { 
			$the_post = $instance['the_post'];
		} else {
			$the_post = '';
		}
		?>
		
		<p>
			<label for="<?php echo $this->get_field_id('the_post'); ?>"><?php _e('Post to feature:', 'buzzblogpro'); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'the_post' ); ?>" name="<?php echo $this->get_field_name( 'the_post' ); ?>">
				<?php foreach($posts_array as $a_post) { ?>
					<option value="<?php echo $a_post->ID; ?>" <?php if ( $a_post->ID == $the_post ) echo 'selected="selected"'; ?>><?php echo $a_post->post_title; ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('hide_image'); ?>">
			<input type="checkbox" id="<?php echo $this->get_field_id('hide_image'); ?>" name="<?php echo $this->get_field_name('hide_image'); ?>" <?php if (isset($instance['hide_image'])) { checked((bool) $instance['hide_image'], true); } ?> /><?php _e('Hide the post image', 'buzzblogpro'); ?></label>
		</p>
	
		
		<p id="<?php echo $this->get_field_id('hide_category'); ?>_wrapper">
			<label for="<?php echo $this->get_field_id('hide_category'); ?>">
			<input type="checkbox" id="<?php echo $this->get_field_id('hide_category'); ?>" name="<?php echo $this->get_field_name('hide_category'); ?>" <?php if (isset($instance['hide_category'])) { checked((bool) $instance['hide_category'], true); } ?> /><?php _e('Hide the post category', 'buzzblogpro'); ?></label>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('hide_title'); ?>">
			<input type="checkbox" id="<?php echo $this->get_field_id('hide_title'); ?>" name="<?php echo $this->get_field_name('hide_title'); ?>" <?php if (isset($instance['hide_title'])) { checked((bool) $instance['hide_title'], true); } ?> /><?php _e('Hide the post title', 'buzzblogpro'); ?></label>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id('hide_author'); ?>">
			<input type="checkbox" id="<?php echo $this->get_field_id('hide_author'); ?>" name="<?php echo $this->get_field_name('hide_author'); ?>" <?php if (isset($instance['hide_author'])) { checked((bool) $instance['hide_author'], true); } ?> /><?php _e('Hide the post author', 'buzzblogpro'); ?></label>
		</p>
			<p>
			<label for="<?php echo $this->get_field_id('hide_date'); ?>">
			<input type="checkbox" id="<?php echo $this->get_field_id('hide_date'); ?>" name="<?php echo $this->get_field_name('hide_date'); ?>" <?php if (isset($instance['hide_date'])) { checked((bool) $instance['hide_date'], true); } ?> /><?php _e('Hide the post date', 'buzzblogpro'); ?></label>
		</p>
					<p>
			<label for="<?php echo $this->get_field_id('hide_comment'); ?>">
			<input type="checkbox" id="<?php echo $this->get_field_id('hide_comment'); ?>" name="<?php echo $this->get_field_name('hide_comment'); ?>" <?php if (isset($instance['hide_comment'])) { checked((bool) $instance['hide_comment'], true); } ?> /><?php _e('Hide the post comment', 'buzzblogpro'); ?></label>
		</p>
		
		
		<p>
			<label for="<?php echo $this->get_field_id('hide_button'); ?>">
			<input type="checkbox" id="<?php echo $this->get_field_id('hide_button'); ?>" name="<?php echo $this->get_field_name('hide_button'); ?>" <?php if (isset($instance['hide_button'])) { checked((bool) $instance['hide_button'], true); } ?> /><?php _e('Hide the "View Post" button', 'buzzblogpro'); ?></label>
		</p>
		<fieldset style="border:1px solid #F1F1F1; padding:10px 10px 0; margin-bottom:1em;">
  <legend style="padding:0 5px;"><?php esc_html_e('Thumbnail', 'buzzblogpro'); ?>:</legend>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id("thumb_width")); ?>">
          <?php esc_html_e( 'Thumb width:', 'buzzblogpro' ); ?>
      </label>
      <input style="text-align: center;" type="text" id="<?php echo esc_attr($this->get_field_id("thumb_width")); ?>" name="<?php echo esc_attr($this->get_field_name("thumb_width")); ?>" value="<?php echo esc_attr($instance["thumb_width"]); ?>" size="3" />
  </p>
      <p>
      <label for="<?php echo esc_attr($this->get_field_id("thumb_height")); ?>">
          <?php esc_html_e( 'Thumb height:', 'buzzblogpro' ); ?>
      </label>
      <input style="text-align: center;" type="text" id="<?php echo esc_attr($this->get_field_id("thumb_height")); ?>" name="<?php echo esc_attr($this->get_field_name("thumb_height")); ?>" value="<?php echo esc_attr($instance["thumb_height"]); ?>" size="3" />
  </p>
  </fieldset>
   <fieldset style="border:1px solid #F1F1F1; padding:10px 10px 0; margin-bottom:1em;">
  <legend style="padding:0 5px;"><?php esc_html_e('Excerpt', 'buzzblogpro'); ?></legend>
  <p>
			<label for="<?php echo $this->get_field_id('hide_excerpt'); ?>">
			<input type="checkbox" id="<?php echo $this->get_field_id('hide_excerpt'); ?>" name="<?php echo $this->get_field_name('hide_excerpt'); ?>" <?php if (isset($instance['hide_excerpt'])) { checked((bool) $instance['hide_excerpt'], true); } ?> /><?php _e('Hide the post excerpt', 'buzzblogpro'); ?></label>
		</p>
  <p>
      <label for="<?php echo esc_attr($this->get_field_id("excerpt_length")); ?>">
          <?php esc_html_e( 'Excerpt length (words):', 'buzzblogpro' ); ?>
      </label>
      <input style="text-align: center;" type="text" id="<?php echo esc_attr($this->get_field_id("excerpt_length")); ?>" name="<?php echo esc_attr($this->get_field_name("excerpt_length")); ?>" value="<?php echo esc_attr($instance["excerpt_length"]); ?>" size="3" />
  </p>
  </fieldset>

		<?php

	}

}